==> bambootracker_0.4.6.orig.tar.gz: BambooTracker-0.4.6/BambooTracker/gui/swap_tracks_dialog.cpp <==
/*
 * Copyright (C) 2020 Rerrah
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */

#include "swap_tracks_dialog.hpp"
#include "ui_swap_tracks_dialog.h"
#include "song.hpp"
#include <QString>
#include "gui/gui_utils.hpp"

SwapTracksDialog::SwapTracksDialog(const SongStyle& style, QWidget *parent) :
	QDialog(parent),
	ui(new Ui::SwapTracksDialog)
{
	ui->setupUi(this);

	setWindowFlags(windowFlags() ^ Qt::WindowContextHelpButtonHint);

	for (const auto& attrib : style.trackAttribs) {
		QString text = gui_utils::getTrackName(style.type, attrib.source, attrib.channelInSource);
		ui->track1ComboBox->addItem(text, attrib.number);
		ui->track2ComboBox->addItem(text, attrib.number);
	}
}

SwapTracksDialog::~SwapTracksDialog()
{
	delete ui;
}

int SwapTracksDialog::getTrack1() const
{
	return ui->track1ComboBox->currentData().toInt();
}

int SwapTracksDialog::getTrack2() const
{
	return ui->track2ComboBox->currentData().toInt();
}

==> bambootracker_0.6.5.orig.tar.gz: BambooTracker-0.6.5/BambooTracker/gui/swap_tracks_dialog.cpp <==
/*
 * Copyright (C) 2020 Rerrah
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */

#include "swap_tracks_dialog.hpp"
#include "ui_swap_tracks_dialog.h"
#include "song.hpp"
#include <QString>
#include "gui/gui_utils.hpp"

SwapTracksDialog::SwapTracksDialog(const SongStyle& style, QWidget *parent) :
	QDialog(parent),
	ui(new Ui::SwapTracksDialog)
{
	ui->setupUi(this);

	setWindowFlags(windowFlags() & ~Qt::WindowContextHelpButtonHint);

	for (const auto& attrib : style.trackAttribs) {
		QString text = gui_utils::getTrackName(style.type, attrib.source, attrib.channelInSource);
		ui->track1ComboBox->addItem(text, attrib.number);
		ui->track2ComboBox->addItem(text, attrib.number);
	}
}

SwapTracksDialog::~SwapTracksDialog()
{
	delete ui;
}

int SwapTracksDialog::getTrack1() const
{
	return ui->track1ComboBox->currentData().toInt();
}

int SwapTracksDialog::getTrack2() const
{
	return ui->track2ComboBox->currentData().toInt();
}
